---
title: <span class="badge object-type-scalar"></span> Rem
---
# <span class="badge object-type-scalar"></span> Rem

Radiation: rem

## Definition

```python
# Radiation: rem
Rem: typing.Literal["radrem"] = "radrem"
```
